package com.chinaitop.depot.business.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.model.GrainOoilReport;
import com.chinaitop.depot.business.service.GrainOoilReportService;
import com.chinaitop.depot.utils.ExcelUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 粮油轮入报表
 * @author hf
 *
 */
@RestController
@RequestMapping(value="/depot/business/grainOoilReport")
@Api(description = "粮油轮入报表")
public class GrainOoilReportController {
	
	@Resource
	private GrainOoilReportService grainOoilReportService;

	/**
	 * 粮油轮入报表列表
	 * @param pageNum	页码
	 * @param pageSize	每页条数
	 * @return
	 */
	@RequestMapping(value="/getListPageInfo", method = RequestMethod.GET)
	@ApiOperation(value="查询粮油轮入报表列表", notes = "查询粮油轮入报表列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
			@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query")
	})
	public PageInfo<Map<Object, Object>> getListPageInfo(Integer pageNum, Integer pageSize, String startDate, String endDate) {
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		Map<Object, Object> map = new HashMap<Object, Object>();
		map.put("startDate", startDate);
		map.put("endDate", endDate);
		List<Map<Object, Object>> list=grainOoilReportService.queryList(map);
		PageInfo<Map<Object, Object>> PageInfo = new PageInfo<Map<Object, Object>>(list);
		return PageInfo;
	}
	
	/**
	 * 导出数据到excel
	 * @return
	 */
	@RequestMapping(value="/exportExcel", method = RequestMethod.POST, produces ="application/json;charset=UTF-8")
	@ResponseBody
	public void exportExcel(HttpServletRequest request, HttpServletResponse response) {
		List<GrainOoilReport> listEnty = new ArrayList<GrainOoilReport>();
		Map<Object, Object> map = new HashMap<Object, Object>();
		map.put("startDate", request.getParameter("startDate"));
		map.put("endDate", request.getParameter("endDate"));
		List<Map<Object, Object>> list=grainOoilReportService.queryList(map);
		float sumInCount = 0f;
		float sumPlanCount = 0f;
		float sumInWcsl = 0f;
		for(Map<Object, Object> obj:list) {
			GrainOoilReport enty = new GrainOoilReport();
			sumInCount+=Float.parseFloat(ObjectUtils.toString(obj.get("in_count")));
			sumPlanCount+=Float.parseFloat(ObjectUtils.toString(obj.get("plan_count")));
			sumInWcsl+=Float.parseFloat(ObjectUtils.toString(obj.get("wcsl")));
			enty.setGrain_kind(ObjectUtils.toString(obj.get("grain_kind")));
			enty.setGrain_attribute(ObjectUtils.toString(obj.get("grain_attribute")));
			enty.setIn_count(ObjectUtils.toString(obj.get("in_count")));
			enty.setPlan_count(ObjectUtils.toString(obj.get("plan_count")));
			enty.setWcsl(ObjectUtils.toString(obj.get("wcsl")));
			enty.setStorehouse_name(ObjectUtils.toString(obj.get("storehouse_name")));
			enty.setWarehouse_name(ObjectUtils.toString(obj.get("warehouse_name")));
			listEnty.add(enty);
		}
		GrainOoilReport enty = new GrainOoilReport();
		enty.setGrain_kind("合计");
		enty.setIn_count(Float.toString(sumInCount));
		enty.setPlan_count(Float.toString(sumPlanCount));
		enty.setWcsl(Float.toString(sumInWcsl));
		listEnty.add(enty);
		
		// JSON字符串转对象
		String orgInfoObject = ObjectUtils.toString(request.getSession().getAttribute("orgInfo"),"");
		Map<String,Object> jsonToMap = JSONObject.parseObject(orgInfoObject);
		String orgName = ObjectUtils.toString(jsonToMap.get("orgName"));
		// 导出操作
		ExcelUtils.exportExcel(listEnty, "粮油轮换情况报表", "sheet1", GrainOoilReport.class, orgName+"-粮油轮换情况报表.xls", response);
	}
	
}
