package com.chinaitop.depot.business.controller;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.model.ReportMonthly;
import com.chinaitop.depot.business.model.ReportMonthlyExample;
import com.chinaitop.depot.business.service.ReportMonthlyService;
import com.chinaitop.depot.utils.HTTPUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.net.URLEncoder;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value="/reportMonthly")
public class ReportMonthlyController {
	
	@Resource
	private ReportMonthlyService reportMonthlyService;

	// 获取ip地址
	@Value("${reportUrlmw}")
	private String reportPath;
	
	/**
	 * 查找信息
	 * @return
	 */
	@RequestMapping(value = "/getReportMonthlyList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询月报表列表", notes = "查询月报表列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "reportPeriod", value = "月", paramType = "query"),
			@ApiImplicitParam(name = "status", value = "状态", paramType = "query"),
			@ApiImplicitParam(name = "filledTime", value = "填报日期", paramType = "query")

	})
	public PageInfo<ReportMonthly> getReportMonthlyList(HttpServletRequest request, Integer pageNum, Integer pageSize, String reportPeriod, String status, String filledTime){
		ReportMonthly record = new ReportMonthly();

		if (StringUtils.isNotBlank(status)){
			record.setStatus(status);
		}
		if(ParameterUtil.isnotnull(filledTime) ){
			//Date starDate = ParameterUtil.string2datetime(filledTime + " 00:00:00");
			record.setFilledTimeCopy(filledTime);

		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		if (StringUtils.isNotBlank(reportPeriod)){
			record.setReportPeriod(reportPeriod);
		}
		List<ReportMonthly> list = reportMonthlyService.getReportMonthlyList(record);
		PageInfo<ReportMonthly> pageInfo = new PageInfo<ReportMonthly>(list);
		return pageInfo;
	}

	/**
	 * 获取ById
	 * @return
	 */
	@RequestMapping(value = "/getReportMonthlyById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取ById", notes = "获取ById")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "id", paramType = "query"),
	})
	public ReportMonthly getReportMonthlyById(Integer id){
		return reportMonthlyService.findById(id);
	}

	/**
	 * 新增
	 * @param reportMonthlyJson
	 * @return
	 */
	@RequestMapping(value = "edit" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="新增数据", notes = "新增数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "paymentJson", value = "JSON数据对象", paramType = "form"),
			@ApiImplicitParam(name = "orgId", value = "登陆人id", paramType = "orgId"),
	})
	public Map<String,String> edit(String reportMonthlyJson,Integer orgId){
		ObjectMapper mapper = new ObjectMapper();
		Map<String,String> map = new HashMap<String, String>();
		try {
			ReportMonthly reportMonthly = (ReportMonthly) mapper.readValue(reportMonthlyJson, ReportMonthly.class);
			reportMonthly.setOrgId(orgId);

			if(ParameterUtil.isnotnull(reportMonthly.getId())){
				reportMonthlyService.update(reportMonthly);
				map.put("status","success");
				map.put("infoCode","200");
			}else{
				reportMonthly.setStatus("0");
				reportMonthlyService.add(reportMonthly);
				map.put("status","success");
				map.put("infoCode","200");
			}
		} catch (IOException e) {
			map.put("status","error");
			map.put("infoCode","500");

		}
		return null;
	}

	/**
	 * 移除
	 * @param id
	 * @return
	 */
	@RequestMapping(value = "remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="按ID删除信息", notes = "按ID删除信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
	})
	public Map<String,String> remove(Integer id){
		Map<String,String> map = new HashMap<String, String>();
		reportMonthlyService.remove(id);
		map.put("status","success");
		return map;
	}


	/**
	 *
	 * 上报月报表
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value="/reportMonthlySave", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="月报表列表", notes = "查询数据列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "reportMonthly", value = "月报表", paramType = "from")
	})
	public Map<String, Object> reportMonthlySave(String reportMonthly) throws Exception {
		// Integer userId = userInfo.getUserId();
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StringBuffer req = new StringBuffer();
		try {
			String mon = URLEncoder.encode(reportMonthly, "UTF-8");
			JSONObject jsonObject = JSONObject.parseObject(reportMonthly);
			String url = reportPath+"/rotation/report/monthly/save";//省平台月报表接口地址
			//String count= HTTPUtils.doPost(url,"?monthlyReport="+jsonObject);
			String count= HTTPUtils.doGet(url+"?monthlyReport="+mon);
			System.out.println("返回值:"+count+"---"+"请求地址："+url);
			System.out.println("上报月报表请求地址以及参数:--"+url+"?monthlyReport="+jsonObject);
			if(count.contains("Success") || count.contains("200")){
				modelMap.put("status", "success");
				modelMap.put("infoCode", 200);
				modelMap.put("msg", "成功！");
			}else if(count.contains("Success") || count.contains("303")){
				modelMap.put("status", "error");
				modelMap.put("infoCode", 303);
				modelMap.put("msg", "重复提交该报表！");
			}
		} catch (Exception e){
			// req.append("?data=");
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("infoCode", 500);
			modelMap.put("msg", "保存失败！");
		}

		return modelMap;
	}

	/**
	 * 上报 修改状态
	 * @param id
	 * @param
	 * @return
	 */
	@RequestMapping(value="/updateMonthlyStatus", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="修改上报状态", notes = "修改上报状态")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "id", paramType = "query"),
			@ApiImplicitParam(name = "status", value = "状态", paramType = "query")
	})
	public Map<String, Object> updateMonthlyStatus(Integer id,Integer status,String totalQuantity,String enterpriseRemark,String provinceRemark,String sendTime) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		ReportMonthly mon = new ReportMonthly();
		try {
			if(id!=null && status!=null){
				mon.setId(id);
				mon.setStatus(String.valueOf(status));
				reportMonthlyService.updateMonthlyStatus(mon);
				modelMap.put("mon", mon);
				modelMap.put("infoCode", 200);
				modelMap.put("status", "success");
			}else{
				throw new RuntimeException("id或status无值");
			}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("infoCode", 500);
			modelMap.put("msg", "保存失败！");
		}

		return modelMap;

	}


}
