package com.chinaitop.depot.business.controller;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.model.ReportWeekly;
import com.chinaitop.depot.business.model.ReportWeeklyExample;
import com.chinaitop.depot.business.service.ReportWeeklyService;
import com.chinaitop.depot.utils.HTTPUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.net.URLEncoder;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value="/reportWeekly")
public class ReportWeeklyController {
	
	@Resource
	private ReportWeeklyService reportWeeklyService;

	// 获取ip地址
	@Value("${reportUrlmw}")
	private String reportPath;
	
	/**
	 * 查找信息
	 * @return
	 */
	@RequestMapping(value = "/getReportWeeklyList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询周报表列表", notes = "查询周报表列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "reportPeriod", value = "周", paramType = "query"),
			@ApiImplicitParam(name = "status", value = "状态", paramType = "query"),
			@ApiImplicitParam(name = "filledTime", value = "填报日期", paramType = "query")

	})
	public PageInfo<ReportWeekly> getReportWeeklyList(Integer pageNum, Integer pageSize, String reportPeriod, String status, String filledTime){
		ReportWeekly example = new ReportWeekly();
		//ReportWeeklyExample.Criteria criteria = example.createCriteria();
		if (StringUtils.isNotBlank(reportPeriod)){
			example.setReportPeriod(reportPeriod);
		}
		if (StringUtils.isNotBlank(status)){
			example.setStatus(status);
		}
		if(ParameterUtil.isnotnull(filledTime) ){
			//Date starDate = ParameterUtil.string2datetime(filledTime + " 00:00:00");
			example.setFilledTimeCopy(filledTime);

		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		List<ReportWeekly> list = reportWeeklyService.getReportWeeklyList(example);
		PageInfo<ReportWeekly> pageInfo = new PageInfo<ReportWeekly>(list);
		return pageInfo;
	}

	/**
	 * 获取ById
	 * @return
	 */
	@RequestMapping(value = "/getReportWeeklyById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取ById", notes = "获取ById")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "id", paramType = "query"),
	})
	public ReportWeekly getReportWeeklyById(Integer id){
		return reportWeeklyService.findById(id);
	}

	/**
	 * 新增
	 * @param reportWeeklyJson
	 * @return
	 */
	@RequestMapping(value = "edit" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="新增数据", notes = "新增数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "paymentJson", value = "JSON数据对象", paramType = "form"),
			@ApiImplicitParam(name = "orgId", value = "登陆人id", paramType = "orgId"),
	})
	public Map<String,String> edit(String reportWeeklyJson,Integer orgId){
		ObjectMapper mapper = new ObjectMapper();
		Map<String,String> map = new HashMap<String, String>();
		try {
			ReportWeekly reportWeekly = (ReportWeekly) mapper.readValue(reportWeeklyJson, ReportWeekly.class);
			reportWeekly.setOrgId(orgId);

			if(ParameterUtil.isnotnull(reportWeekly.getId())){
				reportWeeklyService.update(reportWeekly);
				map.put("status","success");
				map.put("infoCode","200");
			}else{
				reportWeekly.setStatus("0");
				reportWeeklyService.add(reportWeekly);
				map.put("status","success");
				map.put("infoCode","200");
			}
		} catch (IOException e) {
			map.put("status","error");
			map.put("infoCode","500");
		}
		return null;
	}

	/**
	 * 移除
	 * @param id
	 * @return
	 */
	@RequestMapping(value = "remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="按ID删除信息", notes = "按ID删除信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
	})
	public Map<String,String> remove(Integer id){
		Map<String,String> map = new HashMap<String, String>();
		try {
			reportWeeklyService.remove(id);
			map.put("status","success");
			map.put("infoCode","200");
		}catch (Exception e){
			map.put("status","error");
			map.put("infoCode","500");
		}


		return map;
	}


	/**
	 *
	 * 上报周报表
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value="/reportWeeklySave", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="周报表列表", notes = "查询数据列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "reportWeekly", value = "月报表", paramType = "from")
	})
	public Map<String, Object> reportWeeklySave(String reportWeekly) throws Exception {
		// Integer userId = userInfo.getUserId();
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StringBuffer req = new StringBuffer();
		try {
			String weekly = URLEncoder.encode(reportWeekly, "UTF-8");
			JSONObject jsonObject = JSONObject.parseObject(reportWeekly);
			String url = reportPath+"/rotation/report/weekly/save";//省平台周报表接口地址
			String count= HTTPUtils.doGet(url+"?weeklyReport="+weekly);
			//String count= HTTPUtils.doPost(url,jsonObject);
			System.out.println("返回值:"+count+"---"+"请求地址："+url);
			System.out.println("上报周报表请求地址以及参数:--"+url+jsonObject);
			if(count.contains("Success") || count.contains("200")){
				modelMap.put("status", "success");
				modelMap.put("infoCode", 200);
				modelMap.put("msg", "成功！");
			}else if(count.contains("Success") || count.contains("303")){
				modelMap.put("status", "error");
				modelMap.put("infoCode", 303);
				modelMap.put("msg", "重复提交该报表！");
			}
		} catch (Exception e){
			// req.append("?data=");
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("infoCode", 500);
			modelMap.put("msg", "保存失败！");
		}

		return modelMap;
	}

	/**
	 * 上报 修改状态
	 * @param id
	 * @param
	 * @return
	 */
	@RequestMapping(value="/updateWeeklyStatus", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="修改上报状态", notes = "修改上报状态")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "id", paramType = "query"),
			@ApiImplicitParam(name = "status", value = "状态", paramType = "query")
	})
	public Map<String, Object> updateWeeklyStatus(Integer id,Integer status,String totalQuantity,String enterpriseRemark,String provinceRemark,String sendTime) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		ReportWeekly week = new ReportWeekly();
		try {
			if(id!=null && status!=null){
				week.setId(id);
				week.setStatus(String.valueOf(status));
				reportWeeklyService.updateWeeklyStatus(week);
				modelMap.put("week", week);
				modelMap.put("infoCode", 200);
				modelMap.put("status", "success");
			}else{
				throw new RuntimeException("id或status无值");
			}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("infoCode", 500);
			modelMap.put("msg", "保存失败！");
		}

		return modelMap;

	}



}
