package com.chinaitop.depot.business.controller.audit;


import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.act.model.HistoryList;
import com.chinaitop.depot.act.service.ActTaskService;
import com.chinaitop.depot.business.model.BusinessApproval;
import com.chinaitop.depot.business.model.BusinessDeliveryStorageNotice;
import com.chinaitop.depot.business.model.BusinessStoreWareDetail;
import com.chinaitop.depot.business.model.enums.StoreWareType;
import com.chinaitop.depot.business.model.vo.BusinessDeliveryStorageNoticeAuditVO;
import com.chinaitop.depot.business.service.BusinessApprovalService;
import com.chinaitop.depot.business.service.BusinessDeliveryStorageNoticeService;
import com.chinaitop.depot.business.service.BusinessStoreWareDetailService;
import com.chinaitop.depot.utils.activiti.StringUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 粮库业务管理-出入库通知单审批
* <p>Title: BusinessDeliveryStorageNoticeAuditController</p>
* <p>Description: </p>
 */
@RestController
@RequestMapping(value="/depot/business/deliveryStorageNotice/audit")
@Api(value= "BusinessDeliveryStorageNoticeAuditController", description = "出入库通知单审批")
public class BusinessDeliveryStorageNoticeAuditController {
    
    @Resource
    private BusinessDeliveryStorageNoticeService businessDeliveryStorageNoticeService;
    @Resource
    private BusinessStoreWareDetailService businessStoreWareDetailService;
    @Resource
    private BusinessApprovalService businessApprovalService;
    @Resource
    private ActTaskService actTaskService;
    
    /**
     * 获取审批列表.
     * @param pageNum 页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取审批列表", notes = "查询数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "userId", value = "当前登录人id", paramType = "query")
	})
    public PageInfo<BusinessDeliveryStorageNoticeAuditVO> getList(Integer pageNum, Integer pageSize, 
            BusinessDeliveryStorageNotice notice, HttpServletRequest request,Integer userId) {
    	/*UserInfo userInfo= (UserInfo) request.getSession().getAttribute("userInfo");
    	Integer userId = userInfo.getUserId();*/
        PageHelper.startPage(pageNum, pageSize);
        Map<String,Object> paramMap = new HashMap<String, Object>();
        paramMap.put("operator", userId);
        if (StringUtils.isNotEmpty(notice.getBillType())) {
            paramMap.put("billType", notice.getBillType());
        }
        if (StringUtils.isNotBlank(notice.getAuditState())) {
            paramMap.put("result", notice.getAuditState());
        }
        List<BusinessDeliveryStorageNoticeAuditVO> list = businessDeliveryStorageNoticeService.getApprovalList(paramMap);
        PageInfo<BusinessDeliveryStorageNoticeAuditVO> pageInfo = new PageInfo<BusinessDeliveryStorageNoticeAuditVO>(list);
        return pageInfo;
    }
    
    /**
     * 获取审批页面详情.
     * @param id 业务主键
     * @param processInstanceId 流程实例id
     * @return
     */
    @RequestMapping(value="/getAudit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
   	@ApiOperation(value="获取审批页面详情", notes = "获取审批页面详情")
   	@ApiImplicitParams({
   		@ApiImplicitParam(name = "id", value = "通知单id", paramType = "query"),
   		@ApiImplicitParam(name = "processInstanceId", value = "流程实例id", paramType = "query"),
   		@ApiImplicitParam(name = "userName", value = "当前登录人name", paramType = "query")
   	})
    public Map<String, Object> getAduit(Integer id, String processInstanceId,String userName) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // 详情.
        BusinessDeliveryStorageNotice deliveryStorageNotice = businessDeliveryStorageNoticeService.findById(id);
        modelMap.put("deliveryStorageNotice", deliveryStorageNotice);
        
        // 审批列表.
        //List<HistoryList> auditList = actTaskService.histoicFlowList(processInstanceId, null, null);
        //modelMap.put("auditList", auditList);
        
        // 审批列表.
        if(processInstanceId!=null){
        	HistoryList historyList= null;
        	List<HistoryList> auditList = actTaskService.histoicFlowList(processInstanceId, null, null);
        	if(auditList.size()>0 && auditList!=null){
        		for(int i = auditList.size() - 1; i >= 0; i--) { 
        			if(auditList.get(i).getComment().contains("驳回")) {
        				if(i<auditList.size()) {
        					/*if(auditList.get(i).getActivityName().contains("库领导审批")){
        						historyList = auditList.get(i-1);
        					}else{
        						historyList = auditList.get(i);
        					}*/
        					historyList = auditList.get(1);
        					if(historyList!=null){
        						break;
        					}
        				} else {
        					historyList = null;
        				}
        			}
        		}
        	}
			modelMap.put("subAudit", historyList);
        	modelMap.put("auditList", auditList);
        }
        // 仓号货位号数量质量标准.
        List<BusinessStoreWareDetail> storeWareDetailList = null;
        List<BusinessStoreWareDetail> list = null;
        List<Map<String, Object>> map = null;
        List<Map<String, Object>> stopMap = null;
        Map<String, Object> param_map = new HashMap<String, Object>();
        if(deliveryStorageNotice.getPlanBid()!=null && deliveryStorageNotice.getContractBid()==null){//只引用计划 没引用合同 算计划剩余数量
        	// 查询该条通知单引的计划的剩余数量
        	 list= businessStoreWareDetailService.getByZidAndType(deliveryStorageNotice.getPlanBid(), StoreWareType.plan.getValue());
        	//计算每条明细所对应的计划的剩余数量
        	param_map.put("plan_id", deliveryStorageNotice.getPlanBid());
        	if(list.size()>0){
        		if(list.get(0).getHouseId() == 0 && list.get(0).getWarehouseId() == null){//油
        			 map = businessStoreWareDetailService.selectPlanOilUseCount(param_map);
        		}else{
        			 map = businessStoreWareDetailService.selectPlanUseCount(param_map);

        		}
        	}
        	 stopMap = businessStoreWareDetailService.selectPlanUseCountIsStop(param_map);
        }else if(deliveryStorageNotice.getContractBid()!=null){//引用了合同 无论用不用计划 都算的是合同的剩余数量
        	list = businessStoreWareDetailService.getByZidAndType(deliveryStorageNotice.getContractBid(), StoreWareType.contract.getValue());
			param_map.put("contract_id", deliveryStorageNotice.getContractBid());
			if(list.size()>0){
        		if(list.get(0).getHouseId() == 0 && list.get(0).getWarehouseId() == null){//油
        			 map = businessStoreWareDetailService.selectContractOilUseCount(param_map);
        		}else{
        			 map = businessStoreWareDetailService.selectContractUseCount(param_map);
        		}
        	}
			stopMap = businessStoreWareDetailService.selectContractUseCountIsStop(param_map);
        }
            
            
            BusinessStoreWareDetail obj = null;
            double sysl = 0d;
            double sum_use_num = 0d; //已使用总量
            double plan_sum_num = 0d; //原计划数量
            double stop_use_num = 0d; //终止的通知单走完出入库的计划数量
            for (int i = 0; i < list.size(); i++) {
            	obj = list.get(i);
            	for (Map<String, Object> m : map) {
            		if(obj.getHouseId() == 0 && obj.getWarehouseId() == null){//油料
            			if(stopMap.size()>0){
            				for (Map<String, Object> m1 : stopMap) {
								if(m1.get("chID").equals(m.get("house_name").toString())){
									stop_use_num = Double.parseDouble(m1.get("wcsl")+"");
									break;
								}
							}
            			}
            			if (m.get("house_name").equals(obj.getHouseName())) {
                			if (!"".equals(m.get("in_count")) && null != m.get("in_count") && !"".equals(obj.getInCount()) && null != obj.getInCount()) {
                				plan_sum_num = Double.parseDouble(obj.getInCount());
                				sum_use_num = Double.parseDouble(m.get("in_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setRemainingNumber(sysl+""); //页面上明细列表的数量
                					if (sysl == 0) {
                						obj.setRemainingNumber("0");
                					}
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setRemainingNumber("超出:" + sysl);
                				}
                			}
                			if (!"".equals(m.get("out_count")) && null != m.get("out_count") && !"".equals(obj.getOutCount()) && null != obj.getOutCount()) {
                				plan_sum_num = Double.parseDouble(obj.getOutCount());
                				sum_use_num = Double.parseDouble(m.get("out_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setOutRemainingNumber(""+sysl);
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setOutRemainingNumber("超出:" + sysl);
                				}
                			}
                		}
            		}else{
            			if(stopMap.size()>0){
                			for (Map<String, Object> m1 : stopMap) {
								if(m1.get("chID").equals(m.get("house_id").toString()) && m1.get("hwID").equals(m.get("warehouse_id").toString())){
										stop_use_num = Double.parseDouble(m1.get("wcsl")+"");
										break;
								}
							}
                		}
            			if (m.get("house_id").equals(obj.getHouseId()) && m.get("warehouse_id").equals(obj.getWarehouseId())) {
                			if (!"".equals(m.get("in_count")) && null != m.get("in_count") && !"".equals(obj.getInCount()) && null != obj.getInCount()) {
                				plan_sum_num = Double.parseDouble(obj.getInCount());
                				sum_use_num = Double.parseDouble(m.get("in_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setRemainingNumber(sysl+""); //页面上明细列表的数量
                					if (sysl == 0) {
                						obj.setRemainingNumber("0");
                					}
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setRemainingNumber("超出:" + sysl);
                				}
                			}
                			if (!"".equals(m.get("out_count")) && null != m.get("out_count") && !"".equals(obj.getOutCount()) && null != obj.getOutCount()) {
                				plan_sum_num = Double.parseDouble(obj.getOutCount());
                				sum_use_num = Double.parseDouble(m.get("out_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setOutRemainingNumber(""+sysl);
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setOutRemainingNumber("超出:" + sysl);
                				}
                			}
                		}
            		}
            		
            	}
            }

        	// 该条通知单下的明细
	        storeWareDetailList= businessStoreWareDetailService.getByZidAndType(id, StoreWareType.notice.getValue());
	        for (BusinessStoreWareDetail businessPlanDetail : list) {
	        	 for (BusinessStoreWareDetail businessStoreWareDetail : storeWareDetailList) {
	        		 if(businessPlanDetail.getHouseId()==0 && businessPlanDetail.getWarehouseName()!=null){//油
	        			 if(businessPlanDetail.getHouseName().equals(businessStoreWareDetail.getHouseName())){
	        				 if(businessPlanDetail.getRemainingNumber()!=null){
	      							businessStoreWareDetail.setRemainingNumber(businessPlanDetail.getRemainingNumber());
	      						}
	      						if(businessPlanDetail.getOutRemainingNumber()!=null){
	      							businessStoreWareDetail.setOutRemainingNumber(businessPlanDetail.getOutRemainingNumber());
	      						}
	        			 }
	        		 }else{
	        			 if(businessPlanDetail.getHouseId().equals(businessStoreWareDetail.getHouseId()) &&
	      					   businessPlanDetail.getWarehouseId().equals(businessStoreWareDetail.getWarehouseId())){
	      					    
	      						if(businessPlanDetail.getRemainingNumber()!=null){
	      							businessStoreWareDetail.setRemainingNumber(businessPlanDetail.getRemainingNumber());
	      						}
	      						if(businessPlanDetail.getOutRemainingNumber()!=null){
	      							businessStoreWareDetail.setOutRemainingNumber(businessPlanDetail.getOutRemainingNumber());
	      						}
	      						
	      					}
	        		 }
				}
			}
        
        modelMap.put("storeWareDetailList", storeWareDetailList);
        return modelMap;
    }

    /**
     * 审批.
     * @param deliveryStorageNoticeId 业务主键
     * @param businessApproval 中间表
     * @param assignee 下一个环节审批人
     * @param result 当前环节审批结果
     * @return
     */
    @RequestMapping(value="/audit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
   	@ApiOperation(value="通知单审批", notes = "审批")
    @ApiImplicitParams({
   		@ApiImplicitParam(name = "deliveryStorageNoticeId", value = "业务主键", paramType = "query"),
   		@ApiImplicitParam(name = "businessApproval", value = "中间表", paramType = "query"),
   		@ApiImplicitParam(name = "assignee", value = "下一个环节审批人", paramType = "query"),
   		@ApiImplicitParam(name = "result", value = "当前环节审批结果", paramType = "query"),
   		@ApiImplicitParam(name = "name", value = "当前登录人name", paramType = "query")
   	})
    public Map<String, Object> audit(Integer deliveryStorageNoticeId, BusinessApproval businessApproval,String assignee,String result,String name ,HttpServletRequest request) {
    	//UserInfo userInfo= (UserInfo) request.getSession().getAttribute("userInfo");
        Map<String, Object> modelMap = new HashMap<String, Object>();
        businessDeliveryStorageNoticeService.audit(deliveryStorageNoticeId, businessApproval,assignee,result, name);
        modelMap.put("status", "success");
        return modelMap;
    }
    
    /**
     * 获取通知单变更审批列表.
     * @param pageNum 页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value="/getNoticeChangeList",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.GET)
    @ApiOperation(value="获取通知单变更审批列表", notes = "获取通知单变更审批列表，支持分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "userId", value = "当前登录人id", paramType = "query")
    })
   
    public PageInfo<BusinessDeliveryStorageNoticeAuditVO> getNoticeChangeList(Integer pageNum, Integer pageSize,
            HttpServletRequest request, BusinessDeliveryStorageNotice notice,Integer userId) {
        PageHelper.startPage(pageNum, pageSize);
        Map<String,Object> paramMap = new HashMap<String, Object>();
        // TODO 获取当前登录人
        paramMap.put("operator", userId);
        paramMap.put("changeRecordFlag", "1");
        
        if (StringUtils.isNotEmpty(notice.getBillType())) {
            paramMap.put("billType", notice.getBillType());
        }
        if (StringUtils.isNotBlank(notice.getAuditState())) {
            paramMap.put("result", notice.getAuditState());
        }
        List<BusinessDeliveryStorageNoticeAuditVO> list = businessDeliveryStorageNoticeService.getApprovalList(paramMap);
        PageInfo<BusinessDeliveryStorageNoticeAuditVO> pageInfo = new PageInfo<BusinessDeliveryStorageNoticeAuditVO>(list);
        return pageInfo;
    }
	
	
    /**
     * 获取审批页面详情.
     * @param id 业务主键
     * @param processInstanceId 流程实例id
     * @return
     */
    @RequestMapping(value="/getAuditForChange", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
       @ApiOperation(value="获取审批页面详情", notes = "获取审批页面详情")
       @ApiImplicitParams({
           @ApiImplicitParam(name = "id", value = "通知单id", paramType = "query"),
           @ApiImplicitParam(name = "processInstanceId", value = "流程实例id", paramType = "query"),
           @ApiImplicitParam(name = "userName", value = "当前登录人name", paramType = "query")
       })
    public Map<String, Object> getAuditForChange(Integer id, String processInstanceId,String userName) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // 详情.
        BusinessDeliveryStorageNotice deliveryStorageNotice = businessDeliveryStorageNoticeService.findById(id);
        modelMap.put("deliveryStorageNotice", deliveryStorageNotice);
        
        // 审批列表.
        //List<HistoryList> auditList = actTaskService.histoicFlowList(processInstanceId, null, null);
        //modelMap.put("auditList", auditList);
        
        // 审批列表.
        if(processInstanceId!=null){
            HistoryList historyList= null;
            List<HistoryList> auditList = actTaskService.histoicFlowList(processInstanceId, null, null);
            if(auditList.size()>0 && auditList!=null){
                for(int i = auditList.size() - 1; i >= 0; i--) { 
                    if(auditList.get(i).getComment().contains("驳回")) {
                        if(i<auditList.size()) {
                            /*if(auditList.get(i).getActivityName().contains("库领导审批")){
                                historyList = auditList.get(i-1);
                            }else{
                                historyList = auditList.get(i);
                            }*/
                            historyList = auditList.get(1);
                            if(historyList!=null){
                                break;
                            }
                        } else {
                            historyList = null;
                        }
                    }
                }
            }
            modelMap.put("subAudit", historyList);
            modelMap.put("auditList", auditList);
        }
        
        // 获取历史变更详情
        List<BusinessDeliveryStorageNotice> changeDetailList = businessDeliveryStorageNoticeService.getChangeDetailList(id,"");
        modelMap.put("changeDetailList", changeDetailList);
        
        // 仓号货位号数量质量标准.
       /* List<BusinessStoreWareDetail> storeWareDetailList= businessStoreWareDetailService.getByZidAndType(id, StoreWareType.notice.getValue());
        modelMap.put("storeWareDetailList", storeWareDetailList);*/
        
     // 仓号货位号数量质量标准.
        List<BusinessStoreWareDetail> storeWareDetailList = null;
        List<BusinessStoreWareDetail> list = null;
        List<Map<String, Object>> map = null;
        List<Map<String, Object>> stopMap = null;
        Map<String, Object> param_map = new HashMap<String, Object>();
        if(deliveryStorageNotice.getPlanBid()!=null && deliveryStorageNotice.getContractBid()==null){//只引用计划 没引用合同 算计划剩余数量
        	// 查询该条通知单引的计划的剩余数量
        	 list= businessStoreWareDetailService.getByZidAndType(deliveryStorageNotice.getPlanBid(), StoreWareType.plan.getValue());
        	//计算每条明细所对应的计划的剩余数量
        	param_map.put("plan_id", deliveryStorageNotice.getPlanBid());
        	if(list.size()>0){
        		if(list.get(0).getHouseId() == 0 && list.get(0).getWarehouseId() == null){//油
        			 map = businessStoreWareDetailService.selectPlanOilUseCount(param_map);
        		}else{
        			 map = businessStoreWareDetailService.selectPlanUseCount(param_map);

        		}
        	}
        	 stopMap = businessStoreWareDetailService.selectPlanUseCountIsStop(param_map);
        }else if(deliveryStorageNotice.getContractBid()!=null){//引用了合同 无论用不用计划 都算的是合同的剩余数量
        	list = businessStoreWareDetailService.getByZidAndType(deliveryStorageNotice.getContractBid(), StoreWareType.contract.getValue());
			param_map.put("contract_id", deliveryStorageNotice.getContractBid());
			if(list.size()>0){
        		if(list.get(0).getHouseId() == 0 && list.get(0).getWarehouseId() == null){//油
        			 map = businessStoreWareDetailService.selectContractOilUseCount(param_map);
        		}else{
        			 map = businessStoreWareDetailService.selectContractUseCount(param_map);
        		}
        	}
			stopMap = businessStoreWareDetailService.selectContractUseCountIsStop(param_map);
        }
            
            
            BusinessStoreWareDetail obj = null;
            double sysl = 0d;
            double sum_use_num = 0d; //已使用总量
            double plan_sum_num = 0d; //原计划数量
            double stop_use_num = 0d; //终止的通知单走完出入库的计划数量
            for (int i = 0; i < list.size(); i++) {
            	obj = list.get(i);
            	for (Map<String, Object> m : map) {
            		if(obj.getHouseId() == 0 && obj.getWarehouseId() == null){//油料
            			if(stopMap.size()>0){
            				for (Map<String, Object> m1 : stopMap) {
								if(m1.get("chID").equals(m.get("house_name").toString())){
									stop_use_num = Double.parseDouble(m1.get("wcsl")+"");
									break;
								}
							}
            			}
            			if (m.get("house_name").equals(obj.getHouseName())) {
                			if (!"".equals(m.get("in_count")) && null != m.get("in_count") && !"".equals(obj.getInCount()) && null != obj.getInCount()) {
                				plan_sum_num = Double.parseDouble(obj.getInCount());
                				sum_use_num = Double.parseDouble(m.get("in_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setRemainingNumber(sysl+""); //页面上明细列表的数量
                					if (sysl == 0) {
                						obj.setRemainingNumber("0");
                					}
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setRemainingNumber("超出:" + sysl);
                				}
                			}
                			if (!"".equals(m.get("out_count")) && null != m.get("out_count") && !"".equals(obj.getOutCount()) && null != obj.getOutCount()) {
                				plan_sum_num = Double.parseDouble(obj.getOutCount());
                				sum_use_num = Double.parseDouble(m.get("out_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setOutRemainingNumber(""+sysl);
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setOutRemainingNumber("超出:" + sysl);
                				}
                			}
                		}
            		}else{
            			if(stopMap.size()>0){
                			for (Map<String, Object> m1 : stopMap) {
								if(m1.get("chID").equals(m.get("house_id").toString()) && m1.get("hwID").equals(m.get("warehouse_id").toString())){
										stop_use_num = Double.parseDouble(m1.get("wcsl")+"");
										break;
								}
							}
                		}
            			if (m.get("house_id").equals(obj.getHouseId()) && m.get("warehouse_id").equals(obj.getWarehouseId())) {
                			if (!"".equals(m.get("in_count")) && null != m.get("in_count") && !"".equals(obj.getInCount()) && null != obj.getInCount()) {
                				plan_sum_num = Double.parseDouble(obj.getInCount());
                				sum_use_num = Double.parseDouble(m.get("in_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setRemainingNumber(sysl+""); //页面上明细列表的数量
                					if (sysl == 0) {
                						obj.setRemainingNumber("0");
                					}
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setRemainingNumber("超出:" + sysl);
                				}
                			}
                			if (!"".equals(m.get("out_count")) && null != m.get("out_count") && !"".equals(obj.getOutCount()) && null != obj.getOutCount()) {
                				plan_sum_num = Double.parseDouble(obj.getOutCount());
                				sum_use_num = Double.parseDouble(m.get("out_count")+"");
                				if (sum_use_num <= plan_sum_num) {
                					sysl = plan_sum_num - sum_use_num - stop_use_num;
                					obj.setOutRemainingNumber(""+sysl);
                				} else if (sum_use_num > plan_sum_num){
                					sysl = sum_use_num + stop_use_num - plan_sum_num;
                					obj.setOutRemainingNumber("超出:" + sysl);
                				}
                			}
                		}
            		}
            		
            	}
            }

        	// 该条通知单下的明细
	        storeWareDetailList= businessStoreWareDetailService.getByZidAndType(id, StoreWareType.notice.getValue());
	        for (BusinessStoreWareDetail businessPlanDetail : list) {
	        	 for (BusinessStoreWareDetail businessStoreWareDetail : storeWareDetailList) {
	        		 if(businessPlanDetail.getHouseId()==0 && businessPlanDetail.getWarehouseName()!=null){//油
	        			 if(businessPlanDetail.getHouseName().equals(businessStoreWareDetail.getHouseName())){
	        				 if(businessPlanDetail.getRemainingNumber()!=null){
	      							businessStoreWareDetail.setRemainingNumber(businessPlanDetail.getRemainingNumber());
	      						}
	      						if(businessPlanDetail.getOutRemainingNumber()!=null){
	      							businessStoreWareDetail.setOutRemainingNumber(businessPlanDetail.getOutRemainingNumber());
	      						}
	        			 }
	        		 }else{
	        			 if(businessPlanDetail.getHouseId().equals(businessStoreWareDetail.getHouseId()) &&
	      					   businessPlanDetail.getWarehouseId().equals(businessStoreWareDetail.getWarehouseId())){
	      					    
	      						if(businessPlanDetail.getRemainingNumber()!=null){
	      							businessStoreWareDetail.setRemainingNumber(businessPlanDetail.getRemainingNumber());
	      						}
	      						if(businessPlanDetail.getOutRemainingNumber()!=null){
	      							businessStoreWareDetail.setOutRemainingNumber(businessPlanDetail.getOutRemainingNumber());
	      						}
	      						
	      					}
	        		 }
				}
			}
        
        modelMap.put("storeWareDetailList", storeWareDetailList);
        
        return modelMap;
    }
}
