package com.chinaitop.depot.pushs.service.impl;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

import javax.annotation.Resource;

import com.chinaitop.depot.business.mapper.*;
import com.chinaitop.depot.business.model.*;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.pushs.service.PushsService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;

@Service
public class PushServiceImpl implements PushsService{
	
    final static Logger logger  =  LoggerFactory.getLogger(PushServiceImpl.class );


	@Resource
    private BusinessContractMapper businessContractMapper;
	@Resource
	private BusinessDeliveryStorageNoticeMapper businessDeliveryStorageNoticeMapper;
	@Resource
	private BusinessStoreWareDetailMapper businessStoreWareDetailMapper;
	@Resource
    private BusinessLadingMapper ladingMapper;
	@Resource
    private BusinessPlanMapper planMapper;
	@Resource
	private StorageChangeStoragehouseRopMapper storageChangeStoragehouseRopMapper;

	@Resource
	private StorageChangeStoragehouseDefaultMapper storageChangeStoragehouseDefaultMapper;

	@Transactional(rollbackFor = Exception.class)
	@Override
	public String updateContractStatus(String inApplication, String ids) {
		Map<String,Object> mapData = new HashMap<String, Object>();
		//添加查询合同id方法
		BusinessContractExample businessContractExample = new BusinessContractExample();
		BusinessContractExample.Criteria criteria = businessContractExample.createCriteria();
		//传输过来的ids转换成list<Integer>类型的。
		int[] intIds = Arrays.stream(ids.split(",")).mapToInt(Integer::parseInt).toArray();
		Integer[] IntegerIds = ArrayUtils.toObject(intIds);
		criteria.andIdIn(Arrays.asList(IntegerIds));
//		businessContractExample.setOrderByClause("create_time DESC");
		List<BusinessContract> businessContracts = businessContractMapper.selectByExample(businessContractExample);
		if(businessContracts.size() == 0){
			mapData.put("error", "id is error");
			return JSON.toJSONString(ResponseEntity.ok(mapData));
		}
//		criteria.andCreateTimeEqualTo(businessContracts.get(0).getChangeTime());
		//添加要修改的状态值
		BusinessContract businessContract = new BusinessContract();
		businessContract.setInApplication(Integer.parseInt(inApplication));
		businessContractMapper.updateByExampleSelective(businessContract,businessContractExample);

		mapData.put("status", "success");
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}



	@Transactional(rollbackFor = Exception.class)
	@Override
	public String getNoticeDatas(String orgId, String inApplication, String ids ) {
		List<String> listType=new ArrayList<String>();
		listType.add("notice");
		listType.add("transferNotice");
		//先查出主数据
		Map<String,Object> mapCondition = new HashMap<String, Object>();
		mapCondition.put("orgId",orgId);
		mapCondition.put("inApplication",inApplication);
		if(ParameterUtil.isnotnull(ids)) {
			List<String> idsList = Arrays.asList(ids.split(","));
			mapCondition.put("ids", idsList);
		}
		List<Map<String,Object>> mainList =businessDeliveryStorageNoticeMapper.uploadNoticeData(mapCondition);
		//再根据主数据id查出相关的从数据插入
		for (Map<String,Object> mains : mainList) {
			BusinessStoreWareDetailExample businessStoreWareDetailExample = new BusinessStoreWareDetailExample();
			BusinessStoreWareDetailExample.Criteria criteria = businessStoreWareDetailExample.createCriteria();
			criteria.andZidEqualTo(Integer.valueOf(mains.get("id").toString()));
			criteria.andTypeIn(listType);//默认查询通知单类型数据
			List<BusinessStoreWareDetail> json = businessStoreWareDetailMapper.selectByExample(businessStoreWareDetailExample);
			mains.put("fromData",json);//从表数据以json形式插入主表数据
		}

		Map<String,Object> mapCondition1 = new HashMap<String, Object>();
		mapCondition1.put("orgId",orgId);
		if(ParameterUtil.isnotnull(ids)) {
			List<String> idsList = Arrays.asList(ids.split(","));
			mapCondition1.put("ids", idsList);
		}
		List<Map<String,Object>> mainList1 =businessDeliveryStorageNoticeMapper.getNoticeData(mapCondition1);
		//再根据主数据id查出相关的从数据插入
				/*for (Map<String,Object> mains : mainList1) {
					BusinessStoreWareDetailExample businessStoreWareDetailExample = new BusinessStoreWareDetailExample();
					BusinessStoreWareDetailExample.Criteria criteria = businessStoreWareDetailExample.createCriteria();
					criteria.andZidEqualTo(Integer.valueOf(mains.get("id").toString()));
					criteria.andTypeIn(listType);//默认查询通知单类型数据
					List<BusinessStoreWareDetail> json = businessStoreWareDetailMapper.selectByExample(businessStoreWareDetailExample);
					mains.put("fromData1",json);//从表数据以json形式插入主表数据
				}*/
				
        Map<String,Object> mapData = new HashMap<String, Object>();
		mapData.put("status", "success");
		mapData.put("mainData", mainList);
		mapData.put("mainData1", mainList1);
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public String updateNoticeState(String inApplicationJson) {
		Map<String,Object> mapData = new HashMap<String, Object>();
		if (null != inApplicationJson) {
			/* 将获取到的json串转换成json数组 */
			JSONArray json_array = JSONArray.parseArray(inApplicationJson);
			JSONObject json_object = null;

			/* 遍历json数组，获取数组中值 */
			for (Iterator iterator = json_array.iterator(); iterator.hasNext(); ) {

				/* 获取json对象 */
				json_object = (JSONObject) iterator.next();
				if (json_object == null) {
					continue;
				}

				//获取数据
//				String ids = json_object.get("tzdId").toString();
				if (ParameterUtil.isnull(json_object.get("tzdNumber"))) {
					mapData.put("status", "tzdNumber");
					return JSON.toJSONString(ResponseEntity.ok(mapData));
				}
				String numbers = json_object.get("tzdNumber").toString();
				String inApplication = json_object.get("inApplication").toString();

				//添加查询通知单id方法
				BusinessDeliveryStorageNoticeExample noticeExample = new BusinessDeliveryStorageNoticeExample();
				com.chinaitop.depot.business.model.BusinessDeliveryStorageNoticeExample.Criteria noticeCriteria = noticeExample.createCriteria();
				//传输过来的ids转换成list<Integer>类型的。
//				int[] intIds = Arrays.stream(ids.split(",")).mapToInt(Integer::parseInt).toArray();
				String[] strNumbers = numbers.split(",");
//				Integer[] IntegerIds = ArrayUtils.toObject(intIds);
				noticeCriteria.andBillNumberIn(Arrays.asList(strNumbers));
				noticeExample.setOrderByClause(" create_time DESC");
				//添加要修改的状态值
				BusinessDeliveryStorageNotice businessDeliveryStorageNotice = new BusinessDeliveryStorageNotice();
				businessDeliveryStorageNotice.setInApplication(Integer.parseInt(inApplication));
				businessDeliveryStorageNoticeMapper.updateByExampleSelective(businessDeliveryStorageNotice, noticeExample);
			}
		}

		mapData.put("status", "success");
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public String getContractDatas(String orgId, String inApplication, String ids) {
		//查出数据
		Map<String,Object> mapCondition = new HashMap<String, Object>();
		mapCondition.put("inApplication",inApplication);
		if(ParameterUtil.isnotnull(ids)){
			List<String> conList = Arrays.asList(ids.split(","));
			mapCondition.put("ids",conList);
		}
		if(ParameterUtil.isnotnull(orgId)){
			mapCondition.put("orgId",orgId);
		}
		mapCondition.put("contractType",6913);//只查询中转合同
		mapCondition.put("auditState",2);//审批通过的中转合同
		List<Map<String,Object>> mainList =businessContractMapper.contractData(mapCondition);

		//再根据主数据id查出相关的从数据插入
		for (Map<String,Object> mains : mainList) {
			BusinessStoreWareDetailExample businessStoreWareDetailExample = new BusinessStoreWareDetailExample();
			BusinessStoreWareDetailExample.Criteria criteria = businessStoreWareDetailExample.createCriteria();
			criteria.andZidEqualTo(Integer.valueOf(mains.get("id").toString()));
			criteria.andTypeEqualTo("contract");//默认查询通知单类型数据
			criteria.andOrgIdEqualTo(Integer.parseInt(orgId));//查询组织机构id
			List<BusinessStoreWareDetail> json = businessStoreWareDetailMapper.selectByExample(businessStoreWareDetailExample);
			mains.put("fromData",json);//从表数据以json形式插入主表数据
		}

		Map<String,Object> mapData = new HashMap<String, Object>();
		mapData.put("status", "success");
		mapData.put("mainData", mainList);
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public String isHaveTzd(String orgId, String inApplication) {
		//先查出数据
		BusinessDeliveryStorageNoticeExample businessDeliveryStorageNoticeExample = new BusinessDeliveryStorageNoticeExample();
		BusinessDeliveryStorageNoticeExample.Criteria criteria = businessDeliveryStorageNoticeExample.createCriteria();
		//criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
		criteria.andHouseIdEqualTo(Integer.parseInt(orgId)); //若是主库orgId和houseId是一样的  否则houseId是代储库的   orgId是主库
		criteria.andInApplicationEqualTo(Integer.parseInt(inApplication));
		List<BusinessDeliveryStorageNotice> mainList =businessDeliveryStorageNoticeMapper.selectByExample(businessDeliveryStorageNoticeExample);
		//把查出来的所有数据定义一个数组
		List<String> ids = new ArrayList<>();
		for (int i = 0; i < mainList.size(); i++) {
			ids.add(mainList.get(i).getId().toString());
		}
		Map<String,Object> mapData = new HashMap<String, Object>();
		mapData.put("status", "success");
		mapData.put("ids", ids);
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}



	@Override
	public String getLadingDatas(String orgId, String thdhs) {
		
		Map<String,Object> mapCondition = new HashMap<String, Object>();
		mapCondition.put("orgId",orgId);
		if(ParameterUtil.isnotnull(thdhs)) {
			List<String> thdhsList = Arrays.asList(thdhs.split(","));
			mapCondition.put("thdhs", thdhsList);
		}
		
		List<Map<String,Object>> mainList =ladingMapper.getLadingDatas(mapCondition);

        Map<String,Object> mapData = new HashMap<String, Object>();
		mapData.put("status", "success");
		mapData.put("mainData", mainList);
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}


	@Transactional(rollbackFor = Exception.class)
	@Override
	public String updateChangeStorageHouse(String orgId, String applyNo, String foodStatus, String goalNumber) {
		String retS = "Success";
			ObjectMapper mapper = new ObjectMapper();
			StorageChangeStoragehouseDefaultExample StorageChangeStoragehouseDefaultExample = new StorageChangeStoragehouseDefaultExample();
			com.chinaitop.depot.business.model.StorageChangeStoragehouseDefaultExample.Criteria Criteria = StorageChangeStoragehouseDefaultExample.createCriteria();
			StorageChangeStoragehouseRopExample StorageChangeStoragehouseRopExample = new StorageChangeStoragehouseRopExample();
			com.chinaitop.depot.business.model.StorageChangeStoragehouseRopExample.Criteria criteria = StorageChangeStoragehouseRopExample.createCriteria();
			StorageChangeStoragehouseRop StorageChangeStoragehouseRop = new StorageChangeStoragehouseRop();

			Criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
			Criteria.andApplyNoEqualTo(applyNo);
			criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
			criteria.andApplyNoEqualTo(applyNo);
			List<StorageChangeStoragehouseDefault> list = storageChangeStoragehouseDefaultMapper.selectByExample(StorageChangeStoragehouseDefaultExample);
			BigDecimal bigDecimal = new BigDecimal(goalNumber);
		try {
			for(StorageChangeStoragehouseDefault o : list){
				StorageChangeStoragehouseRop.setApplyFirm(o.getApplyFirm());   //申请倒仓企业
				StorageChangeStoragehouseRop.setChangehouseNo(o.getChangehouseNo());  //倒仓通知单编号
				StorageChangeStoragehouseRop.setApplyTime(o.getApplyTime());   //申请日期
				StorageChangeStoragehouseRop.setOutStorehouse(o.getOutStorehouse());  //倒出仓房
				StorageChangeStoragehouseRop.setOutStorehouseName(o.getOutStorehouseName());   //倒出仓房名称
				StorageChangeStoragehouseRop.setOutWarehouse(o.getOutWarehouse());     //倒出货位
				StorageChangeStoragehouseRop.setOutWarehouseName(o.getOutWarehouseName());  //倒出货位名称
				StorageChangeStoragehouseRop.setFoodWar(o.getFoodWar());   //粮食品种
				StorageChangeStoragehouseRop.setFoodStatus(foodStatus);  //完成状态
				StorageChangeStoragehouseRop.setFoodNature(o.getFoodNature());   //粮食性质
				StorageChangeStoragehouseRop.setBitWeigh(o.getBitWeigh());   //是否称重
				StorageChangeStoragehouseRop.setOutBefore(o.getOutBefore());  //倒出前保存方式
				StorageChangeStoragehouseRop.setCreateTime(o.getCreateTime());  //接收日期
				StorageChangeStoragehouseRop.setIntoStorehouse(o.getIntoStorehouse());  //倒入仓房
				StorageChangeStoragehouseRop.setIntoStorehouseName(o.getIntoStorehouseName());   //倒入仓房名称
				StorageChangeStoragehouseRop.setIntoWarehouse(o.getIntoWarehouse());  //倒入货位
				StorageChangeStoragehouseRop.setIntoWarehouseName(o.getIntoWarehouseName());   //倒入货位名称
				StorageChangeStoragehouseRop.setDetailWar(o.getDetailWar());   //明细品种
				StorageChangeStoragehouseRop.setFoodNumber(o.getFoodNumber());   //粮食数量(公斤)
				StorageChangeStoragehouseRop.setGoalNumber(bigDecimal);   //目标数量
				StorageChangeStoragehouseRop.setOutAfter(o.getOutAfter());  //倒出后保管方式
				StorageChangeStoragehouseRop.setOperStaff(o.getOperStaff());   //操作人员
				StorageChangeStoragehouseRop.setOrgId(Integer.parseInt(orgId));   //单位ID
				StorageChangeStoragehouseRop.setApplyNo(applyNo);  //申请单号
			}
			List<StorageChangeStoragehouseRop> ropList = storageChangeStoragehouseRopMapper.selectByExample(StorageChangeStoragehouseRopExample);
			if(ropList == null || ropList.size() ==0 ){
				storageChangeStoragehouseRopMapper.insertSelective(StorageChangeStoragehouseRop);
			}else{
				storageChangeStoragehouseRopMapper.updateByPrimaryKeySelective(StorageChangeStoragehouseRop);
			}
		} catch (Exception e) {
			return retS = "error";
		}
		return retS;
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public String getChangeDatas(String orgId, String ids) {
		//查出数据
		Map<String,Object> mapCondition = new HashMap<String, Object>();
		if(ParameterUtil.isnotnull(ids)){
			List<String> conList = Arrays.asList(ids.split(","));
			mapCondition.put("ids",conList);
		}
		if(ParameterUtil.isnotnull(orgId)){
			mapCondition.put("orgId",orgId);
		}
		List<Map<String,Object>> mainList =storageChangeStoragehouseDefaultMapper.contractData(mapCondition);

		Map<String,Object> mapData = new HashMap<String, Object>();
		mapData.put("status", "success");
		mapData.put("mainData", mainList);
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}



	@Transactional(rollbackFor = Exception.class)
	@Override
	public String receiveTzd(String orgId, String data) {
		// TODO Auto-generated method stub
		Map<String,Object> map = new HashMap<String, Object>();
		Map<String,Object> mapCustomer = new HashMap<String, Object>();

		//JSON字符串转 json对象
        JSONObject jsonObject = JSONObject.parseObject(data);
		JSONObject zbObject=jsonObject.getJSONObject("mainData");
	    String contract=zbObject.getString("htbh");//合同编号
	    String planNumber=zbObject.getString("jhdbh"); //计划编号
	    String shipingCount=zbObject.getString("sl");//数量
	    String moneyQuantity=zbObject.getString("je"); //金额
	    String creater=zbObject.getString("kdr");//开单人
	
		//try {
			Date createTime = zbObject.getDate("kdsj");//开单时间
			String billTypeId=zbObject.getString("cczyfl");//作业分类
		    String billNumber=zbObject.getString("tzdbh");//通知单编号
		    String deliveryCustomer=zbObject.getString("slr");//客户名称
		    String mobile=zbObject.getString("slrdh");//客户电话
		    String identification=zbObject.getString("slrsfzh");//客户证件号
		    //String hhyhmc=zbObject.getString("hhyhmc");//开户银行名称
		    //String hfyhhb=zbObject.getString("hfyhhb");//开户银行行别
		    //String yhkh=zbObject.getString("yhkh");//银行卡号
		    //String jhkh=zbObject.getString("jhkh");//计划客户
		    //String skr=zbObject.getString("skr");//收款人
		    String qualityStandard=zbObject.getString("ysfs");//运输方式
		    
		    if(contract.equals("0") && planNumber.equals("0")){
		    	map.put("msg", "计划和合同编号都为空");
		    	map.put("success", false);
		    }else{
		    	//判断该合同编号是否合格
			    Integer contractBid = 0;
			    if(null != contract && !contract.equals("0")){
			    	BusinessContractExample businessContractExample = new BusinessContractExample();
					BusinessContractExample.Criteria criteria = businessContractExample.createCriteria();
					criteria.andContractNumberEqualTo(contract);
					criteria.andOrgIdEqualTo(Integer.valueOf(orgId));
					businessContractExample.setOrderByClause("id desc");
					List<BusinessContract> contractList = businessContractMapper.selectByExample(businessContractExample);
					if(contractList!=null && contractList.size()>0){
						 contractBid = contractList.get(0).getId();
					}else{
						map.put("success", false);
						map.put("msg", "该合同编号不存在");
					}
			    }
			    
			  //判断该计划编号是否合格
			    Integer planBid = 0;
			    if(null != planNumber && !planNumber.equals("0")){
			    	BusinessPlanExample businessPlanExample = new BusinessPlanExample();
			    	BusinessPlanExample.Criteria criteria = businessPlanExample.createCriteria();
			    	criteria.andPlanNumberEqualTo(planNumber);
			    	criteria.andOrgIdEqualTo(Integer.valueOf(orgId));
			    	businessPlanExample.setOrderByClause("id desc");
			    	List<BusinessPlan> planList = planMapper.selectByExample(businessPlanExample);
			    	if(planList!=null && planList.size()>0){
			    		planBid = planList.get(0).getId();
			    	}else{
			    		map.put("success", false);
						map.put("msg", "该计划编号不存在");
			    	}
			    }
			    
			    //判断客户是否合格(根据客户的名称和身份证获取客户信息)
			    mapCustomer.put("deliveryCustomer", deliveryCustomer);
			    mapCustomer.put("identification", identification);
			    mapCustomer.put("orgId", orgId);
			    Integer customerBid = businessDeliveryStorageNoticeMapper.selectCustomer(mapCustomer);
			    if(customerBid==null || customerBid == 0){
			    	map.put("success", false);
					map.put("msg", "该客户不存在或者该客户信息有误");
			    }else{
			    	if(planBid!=0 || contractBid!=0){

				    	//主表数据的新增
						BusinessDeliveryStorageNotice notice = new BusinessDeliveryStorageNotice();
						if(billTypeId.equals("2816")){
							 notice.setBillType("1");
						}else if(billTypeId.equals("2818")){
							notice.setBillType("3");
						}
						notice.setBillTypeId(Integer.valueOf(billTypeId));
						notice.setBillNumber(billNumber);
						notice.setShipingCount(shipingCount);
						notice.setMobile(mobile);
						notice.setCustomerBid(customerBid);//客户id
						notice.setDeliveryCustomer(deliveryCustomer);//客户名称
						if(!planNumber.equals("0")){
							notice.setPlanNumber(planNumber);
							notice.setPlanBid(planBid);//计划id
						}
						if(!contract.equals("0")){
							notice.setContract(contract);
							notice.setContractBid(contractBid);//合同id
							notice.setRootContractBid(contractBid);
						}
						
						//notice.setBillMemo(billMemo); //备注
						notice.setMoneyQuantity(moneyQuantity);
						notice.setAuditState("2");//默认审批通过
						notice.setQualityStandard(qualityStandard);//对应字典表的值
						notice.setBillMan(creater); //开单人名称
						//notice.setBillDate(zbObject.getDate(zbObject.get("kdsj"))); //开单人日期
						notice.setHouseId(Integer.valueOf(orgId)); //如果是代储 则是代储的orgId
						notice.setCreater(creater);
						notice.setCreateTime(createTime);
						notice.setBillDate(createTime);
						//notice.setCreateDepot(); //暂停或终止的原因
						notice.setOrgId(Integer.valueOf(orgId));
						notice.setInApplication(1);//在用的默认
						//notice.setCreaterId(creater); //创建人名称
						//notice.setRootContractBid(rootContractBid);
						notice.setIdentification(identification);
						//notice.setCarnumber(carnumber);
						Date date = new Date();
						notice.setUpdateTime(date);
						notice.setAgreeTime(date);
						int a = businessDeliveryStorageNoticeMapper.insert(notice);
						if(a!=0){
							//从表数据的新增
							JSONArray jsonArray = jsonObject.getJSONArray("fltDatas"); 
							JSONObject cb = null;  
							for (int i = 0; i < jsonArray.size(); i++) {  
							   cb = jsonArray.getJSONObject(i);  
							   String chId = cb.getString("chID");
							   String chmc = cb.getString("chmc");
							   String hwID = cb.getString("hwID");
							   String hwhmc = cb.getString("hwhmc");
							   String grainKind = cb.getString("grain_kind");
							   String grainDetailKind = cb.getString("grain_detail_kind");
							   String grainGrade = cb.getString("grain_grade");
							   String grainAnnual = cb.getString("grain_annual");
							   String grainProducingArea = cb.getString("grain_producing_area");
							   String price = cb.getString("price");
							   String count = cb.getString("count");
							   String detailTotalPrice = cb.getString("detail_total_price");
							   String grainAttribute = cb.getString("grain_attribute");
							   BusinessStoreWareDetail detail = new BusinessStoreWareDetail();
							   if(null != chId && null != hwID){
								   if(hwID.equals(chId)){
									   detail.setHouseId(0);
									   detail.setHouseName(chId);
									   detail.setWarehouseName(hwhmc);
								   }else{
									   detail.setHouseId(Integer.valueOf(chId));
									   detail.setHouseName(chmc);
									   detail.setWarehouseId(Integer.valueOf(hwID));
									   detail.setWarehouseName(hwhmc);
								   }
							   }
							   detail.setZid(notice.getId());
							   detail.setType("notice");
							   detail.setState(Integer.valueOf(orgId));
							   detail.setCreateTime(createTime);
							   detail.setOrgId(Integer.valueOf(orgId));
							   detail.setGrainKind(Integer.valueOf(grainKind));
							   detail.setGrainDetailKind(Integer.valueOf(grainDetailKind));
							   detail.setGrainAnnual(Integer.valueOf(grainAnnual)); //收获年度
							   detail.setGrainAttribute(Integer.valueOf(grainAttribute));
							   detail.setGrainGrade(Integer.valueOf(grainGrade));
							   detail.setGrainProducingArea(Integer.valueOf(grainProducingArea));
							   if(billTypeId.equals("2816")){//入库
								   detail.setInCount(count);
								   detail.setInPrice(price);
								   detail.setInDetailTotalPrice(detailTotalPrice);
							   }else if(billTypeId.equals("2818")){//出库
								   detail.setOutCount(count);
								   detail.setOutPrice(price);
								   detail.setOutDetailTotalPrice(detailTotalPrice);
							   }
							   int fhzt = businessStoreWareDetailMapper.insert(detail);
							   if(fhzt==0){
								   map.put("success", false);
								   map.put("msg", "从表数据保存失败");
							   }else{
								   map.put("success", true);
								   map.put("htid", contractBid);
								   map.put("tzdid", notice.getId());
								   map.put("jhdid", planBid);
							   }
						   } 
						}else{
							map.put("success", false);
							map.put("msg", "从表数据保存失败");
						}
				    
			    	
			    	}else{
			    		map.put("success", false);
						map.put("msg", "该计划或合同编号不存在");
			    	}
			    }
			    
		    }
		    
		return map.toString();
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public String uploadNoticeUnwind(String orgId, String houseId) {

		//先根据仓房id从通知单子表查出来相关联的通知单id集合
		BusinessStoreWareDetailExample businessStoreWareDetailExample = new BusinessStoreWareDetailExample();
		BusinessStoreWareDetailExample.Criteria criteria = businessStoreWareDetailExample.createCriteria();
		criteria.andHouseIdEqualTo(Integer.parseInt(houseId));
		criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
		criteria.andTypeEqualTo("notice");//默认查询通知单类型数据
		List<BusinessStoreWareDetail> json = businessStoreWareDetailMapper.selectByExample(businessStoreWareDetailExample);

		List<String> noticeIds = new ArrayList<>();
		if (!ParameterUtil.isequal(0,json.size())) {
			for (int i = 0; i < json.size(); i++) {
				noticeIds.add(json.get(i).getZid().toString());
			}

			//查出数据
			Map<String,Object> mapCondition = new HashMap<String, Object>();
			if(ParameterUtil.isnotnull(noticeIds)){
				mapCondition.put("ids",noticeIds);
			}
			if(ParameterUtil.isnotnull(orgId)){
				mapCondition.put("orgId",orgId);
			}
			businessDeliveryStorageNoticeMapper.uploadNoticeUnwind(mapCondition);
		}

		Map<String,Object> mapData = new HashMap<String, Object>();
		mapData.put("status", "success");
		return JSON.toJSONString(ResponseEntity.ok(mapData));
	}
}
