package com.chinaitop.depot.tour.controller;

import com.chinaitop.depot.business.model.BusinessFile;
import com.chinaitop.depot.business.model.BusinessPlan;
import com.chinaitop.depot.tour.model.BusinessTour;
import com.chinaitop.depot.tour.service.TourService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 轮换巡报
 * 
 */
@RestController
@RequestMapping(value="/depot/business/tour")
@Api(value= "TourController", description = "轮换巡报")
public class TourController {

    @Resource
    private TourService tourService;

    /**
     * 轮换巡报列表
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="轮换巡报列表", notes = "查询数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "业务发生开始时间", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "业务发生结束时间", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房编号", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构代码", paramType = "query")
    })
    public PageInfo<BusinessTour> getList(Integer pageNum, Integer pageSize, String startTime , String endTime , String houseId , String orgId) throws Exception {

        List<BusinessTour> list = tourService.queryByExample(pageNum, pageSize, startTime, endTime, houseId, orgId);
        PageInfo<BusinessTour> pageInfo = new PageInfo<BusinessTour>(list);
        return pageInfo;
    }

    /**
     * 根据id查询
     * @param id 主键
     * @return
     */
    @RequestMapping(value="/loadDataById", produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.GET)
    @ApiOperation(value="根据id查找信息", notes = "根据id查找")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "轮换巡报id", paramType = "query")
    })
    public Map<String, Object> loadDataById(Integer id) {
        return tourService.findById(id);
    }

    /**
     * 保存轮换巡报数据
     * @param tourJson 轮换巡报
     * @return
     */
    @RequestMapping(value = "/saveAndUpdate",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="保存轮换巡报数据", notes = "保存轮换巡报数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tourJson", value = "轮换巡报", paramType = "form")
    })
    public Map<String, Object> saveAndUpdate(String tourJson) {
        return tourService.saveAndUpdate(tourJson);
    }

    /**
     * 根据id查询
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/removeTourPeople",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="删除轮换巡报数据", notes = "根据id删除轮换巡报数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键", paramType = "form")
    })
    public Map<String, Object> removeTourPeople(String id) {
        return tourService.removeTourPeople(id);
    }
}