package com.chinaitop.depot.tour.service.impl;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.chinaitop.depot.business.model.BusinessPlan;
import com.chinaitop.depot.business.model.BusinessPlanExample;
import com.chinaitop.depot.tour.mapper.BusinessTourMapper;
import com.chinaitop.depot.tour.model.BusinessTour;
import com.chinaitop.depot.tour.model.BusinessTourExample;
import com.chinaitop.depot.tour.service.TourService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Service;

@Service
public class TourServiceImpl implements TourService {
    
    @Resource
    private BusinessTourMapper tourMapper;

    @Override
    public List<BusinessTour> queryByExample(Integer pageNum, Integer pageSize, String startTime , String endTime , String houseId , String orgId) {
        BusinessTourExample example = new BusinessTourExample();
        BusinessTourExample.Criteria createCriteria = example.createCriteria();

        //填写时间
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime)) {
            createCriteria.andCreateTimeBetween(ParameterUtil.string2datetime(startTime+ParameterUtil.startTime), ParameterUtil.string2datetime(endTime+ParameterUtil.endTime));
        } else if (ParameterUtil.isnotnull(startTime)) {
            createCriteria.andCreateTimeGreaterThan(ParameterUtil.string2datetime(startTime+ParameterUtil.startTime));
        } else if (ParameterUtil.isnotnull(endTime)) {
            createCriteria.andCreateTimeLessThan(ParameterUtil.string2datetime(endTime+ParameterUtil.endTime));
        }
        if (orgId != null) {
            createCriteria.andOrgIdEqualTo(Integer.parseInt(orgId));
        }

        if (houseId != null) {
            createCriteria.andIntoHouseIdEqualTo(Integer.parseInt(houseId));
            createCriteria.andIntoHouseIdIsNull();

            createCriteria.andOutHouseIdEqualTo(Integer.parseInt(houseId));
            createCriteria.andOutHouseIdIsNull();
        }

        //分页
        if (null != pageNum && null != pageSize) {
            PageHelper.startPage(pageNum, pageSize);
        }
        return tourMapper.selectByExample(example);
    }

    @Override
    public Map<String, Object> findById(Integer id) {

        Map<String, Object> modelMap = new HashMap<String, Object>();
        BusinessTour businessTour = new BusinessTour();
        if (id != null) {
            businessTour = tourMapper.selectByPrimaryKey(id);
        }else{
            businessTour=new BusinessTour();
        }
        modelMap.put("tour", businessTour);
        return modelMap;
    }

    @Override
    public Map<String, Object> saveAndUpdate(String tourJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        BusinessTour businessTour = null;
        try {
            businessTour = (BusinessTour)mapper.readValue(tourJson, BusinessTour.class);
            if (ParameterUtil.isnull(businessTour.getId())) {
                tourMapper.insertSelective(businessTour);
            }else{
                tourMapper.updateByPrimaryKeySelective(businessTour);
            }
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    @Override
    public Map<String, Object> removeTourPeople(String id) {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            tourMapper.deleteByPrimaryKey(Integer.parseInt(id));
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }
}
